.. module:: enaml.application

=================
enaml.application
=================

.. rubric:: Functions

.. autosummary::
    :nosignatures:

    deferred_call
    is_main_thread
    schedule
    timed_call


.. rubric:: Classes

.. autosummary::
    :nosignatures:

    Application
    ProxyResolver
    ScheduledTask


.. autofunction:: deferred_call

.. autofunction:: is_main_thread

.. autofunction:: schedule

.. autofunction:: timed_call

.. autoclass:: Application

.. autoclass:: ProxyResolver

.. autoclass:: ScheduledTask
